@@ -43,7 +43,7 @@ public:
 
 void AddHostDialogPrivate::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "AddHostDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "AddHostDialog");
     const QSize size = group.readEntry("Size", QSize(600, 400));
     if (size.isValid()) {
         q->resize(size);
@@ -52,7 +52,7 @@ void AddHostDialogPrivate::readConfig()
 
 void AddHostDialogPrivate::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "AddHostDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "AddHostDialog");
     group.writeEntry("Size", q->size());
     group.sync();
 }
@@ -63,7 +63,7 @@ AddHostDialog::AddHostDialog(KLDAP::LdapServer *server, QWidget *parent)
 {
     setWindowTitle(i18nc("@title:window", "Add Host"));
     auto mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     d->mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     d->mOkButton->setDefault(true);
     d->mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -73,7 +73,7 @@ AddHostDialog::AddHostDialog(KLDAP::LdapServer *server, QWidget *parent)
 
     d->mServer = server;
 
-    QWidget *page = new QWidget(this);
+    auto page = new QWidget(this);
     mainLayout->addWidget(page);
     mainLayout->addWidget(buttonBox);
     auto layout = new QHBoxLayout(page);
